@@ -176,9 +176,7 @@ VisualFreeBusyWidget::VisualFreeBusyWidget(CalendarSupport::FreeBusyItemModel *m
     mScaleCombo->addItem(i18nc("@item:inlistbox range is computed automatically", "Automatic"),
                          QVariant::fromValue<int>(KGantt::DateTimeGrid::ScaleAuto));
     mScaleCombo->setCurrentIndex(0);   // start with "hour"
-    connect(mScaleCombo, static_cast<void (KComboBox::*)(
-                                         int)>(&KComboBox::activated), this,
-            &VisualFreeBusyWidget::slotScaleChanged);
+    connect(mScaleCombo, QOverload< int>::of(&KComboBox::activated), this, &VisualFreeBusyWidget::slotScaleChanged);
     controlLayout->addWidget(mScaleCombo);
 
     QPushButton *button = new QPushButton(i18nc("@action:button", "Center on Start"), this);
@@ -268,22 +266,11 @@ VisualFreeBusyWidget::VisualFreeBusyWidget(CalendarSupport::FreeBusyItemModel *m
     // set start to even hours, i.e. to 12:AM 0 Min 0 Sec
     QDateTime horizonStart
         = QDateTime(QDateTime::currentDateTime().addDays(-15).date());
-    //QDateTime horizonEnd = QDateTime::currentDateTime().addDays(15);
     mGanttGrid->setStartDateTime(horizonStart);
 
-//connect( mGanttGraphicsView, SIGNAL(timeIntervalSelected(KDateTime,KDateTime)),
-//         mGanttGraphicsView, SLOT(zoomToSelection(KDateTime,KDateTime)) );
-//connect( mGanttGraphicsView, SIGNAL(doubleClicked(QModelIndex)),
-//         SLOT(editFreeBusyUrl(QModelIndex)) );
-//connect(mGanttGraphicsView,SIGNAL(intervalColorRectangleMoved(KDateTime,KDateTime)),
-//        this, SLOT(slotIntervalColorRectangleMoved(KDateTime,KDateTime)) );
-
     connect(mLeftView, &QTreeView::customContextMenuRequested, this,
             &VisualFreeBusyWidget::showAttendeeStatusMenu);
 
-//   foreach ( FreeBusyItem::Ptr item, mResolver->freeBusyItems() ) {
-//     newFreeBusy( item );
-//   }
 }
 
 VisualFreeBusyWidget::~VisualFreeBusyWidget()
@@ -297,12 +284,12 @@ void VisualFreeBusyWidget::showAttendeeStatusMenu()
 void VisualFreeBusyWidget::slotCenterOnStart()
 {
     KGantt::DateTimeGrid *grid = static_cast<KGantt::DateTimeGrid *>(mGanttGraphicsView->grid());
-    int daysTo = grid->startDateTime().daysTo(mDtStart.dateTime());
+    int daysTo = grid->startDateTime().daysTo(mDtStart);
     mGanttGraphicsView->horizontalScrollBar()->setValue(daysTo * 800);
 }
 
-void VisualFreeBusyWidget::slotIntervalColorRectangleMoved(const KDateTime &start,
-                                                           const KDateTime &end)
+void VisualFreeBusyWidget::slotIntervalColorRectangleMoved(const QDateTime &start,
+                                                           const QDateTime &end)
 {
     mDtStart = start;
     mDtEnd = end;
@@ -325,8 +312,8 @@ void VisualFreeBusyWidget::slotScaleChanged(int newScale)
     mGanttGrid->setScale((KGantt::DateTimeGrid::Scale)value);
 }
 
-void VisualFreeBusyWidget::slotUpdateIncidenceStartEnd(const KDateTime &dtFrom,
-                                                       const KDateTime &dtTo)
+void VisualFreeBusyWidget::slotUpdateIncidenceStartEnd(const QDateTime &dtFrom,
+                                                       const QDateTime &dtTo)
 {
     mDtStart = dtFrom;
     mDtEnd = dtTo;
